pub fn load_both(
fs: &dyn Filesystem,
paths: &ConfigPaths,
) -> Result<BTreeMap<InstallScope, LockFile>>Expand description
Load both the global and local lock files in one call.
Returns a BTreeMap keyed by InstallScope.
pub fn load_both(
fs: &dyn Filesystem,
paths: &ConfigPaths,
) -> Result<BTreeMap<InstallScope, LockFile>>Load both the global and local lock files in one call.
Returns a BTreeMap keyed by InstallScope.