pub fn load_from(path: &Path, fs: &dyn Filesystem) -> Result<LockFile>Expand description
Load a LockFile from an explicit path via the given filesystem.
Returns a default (empty) lock file if the path does not exist.
pub fn load_from(path: &Path, fs: &dyn Filesystem) -> Result<LockFile>Load a LockFile from an explicit path via the given filesystem.
Returns a default (empty) lock file if the path does not exist.