pub struct InstallPlan {
pub tool: ToolIdentity,
pub scope: InstallScope,
pub source_checksum: String,
pub cmx_present: bool,
pub force: bool,
pub targets: Vec<TargetPlan>,
}Expand description
The full installation plan — computed from source metadata, with no writes.
Fields
tool: ToolIdentityscope: InstallScopesource_checksum: Stringcmx_present: boolWhether cmx is managing this machine (config or non-empty lock exists).
force: booltargets: Vec<TargetPlan>Implementations
Sourceimpl InstallPlan
impl InstallPlan
Sourcepub fn is_blocked(&self) -> bool
pub fn is_blocked(&self) -> bool
Returns true if any target action is blocked (e.g. RefuseNewer).
Sourcepub fn write_count(&self) -> usize
pub fn write_count(&self) -> usize
The number of targets that will write files to disk.